@@ -1,37 +1,19 @@
 /* -*- C++ -*-
+    This file contains a testsuite for global queue customizations in ThreadWeaver.
 
-   This file contains a testsuite for global queue customizations in ThreadWeaver.
+    SPDX-FileCopyrightText: 2005-2013 Mirko Boehm <mirko@kde.org>
 
-   $ Author: Mirko Boehm $
-   $ Copyright: (C) 2005-2013 Mirko Boehm $
-   $ Contact: mirko@kde.org
-         https://www.kde.org
-         http://creative-destruction.me $
-
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include <QString>
 #include <QTest>
 
-#include <ThreadWeaver/ThreadWeaver>
-#include <ThreadWeaver/QueueSignals>
-#include <ThreadWeaver/Queue>
-#include <weaver.h>
 #include <ThreadWeaver/IdDecorator>
+#include <ThreadWeaver/Queue>
+#include <ThreadWeaver/QueueSignals>
+#include <ThreadWeaver/ThreadWeaver>
+#include <weaver.h>
 
 using namespace ThreadWeaver;
 QAtomicInt counter;
@@ -42,9 +24,11 @@ public:
     explicit CountingJobDecorator(const JobPointer &job)
         : IdDecorator(job.data(), false)
         , original_(job)
-    {}
+    {
+    }
 
-    void run(JobPointer self, Thread *thread) override {
+    void run(JobPointer self, Thread *thread) override
+    {
         counter.fetchAndAddRelease(1);
         IdDecorator::run(self, thread);
         counter.fetchAndAddAcquire(1);
@@ -57,12 +41,14 @@ class JobCountingWeaver : public Weaver
 {
     Q_OBJECT
 public:
-    explicit JobCountingWeaver(QObject *parent = nullptr) : Weaver(parent) {}
-    void enqueue(const QVector<JobPointer> &jobs) override {
-        QVector<JobPointer> decorated;
-        std::transform(jobs.begin(), jobs.end(), std::back_inserter(decorated),
-        [](const JobPointer & job)
-        {
+    explicit JobCountingWeaver(QObject *parent = nullptr)
+        : Weaver(parent)
+    {
+    }
+    void enqueue(const QList<JobPointer> &jobs) override
+    {
+        QList<JobPointer> decorated;
+        std::transform(jobs.begin(), jobs.end(), std::back_inserter(decorated), [](const JobPointer &job) {
             return JobPointer(new CountingJobDecorator(job));
         });
         Weaver::enqueue(decorated);
@@ -71,7 +57,8 @@ public:
 
 class CountingGlobalQueueFactory : public Queue::GlobalQueueFactory
 {
-    Queue *create(QObject *parent = nullptr) override {
+    Queue *create(QObject *parent = nullptr) override
+    {
         return new Queue(new JobCountingWeaver, parent);
     }
 };
@@ -87,7 +74,7 @@ private Q_SLOTS:
         counter.storeRelease(0);
         QCoreApplication app(argc, (char **)nullptr);
         Queue queue(new JobCountingWeaver(this));
-        queue.enqueue(make_job([]() {}));  // nop
+        queue.enqueue(make_job([]() {})); // nop
         queue.finish();
         QCOMPARE(counter.loadAcquire(), 2);
     }
@@ -97,7 +84,7 @@ private Q_SLOTS:
         Queue::setGlobalQueueFactory(new CountingGlobalQueueFactory());
         QCoreApplication app(argc, (char **)nullptr);
         counter.storeRelease(0);
-        Queue::instance()->enqueue(make_job([]() {}));  // nop
+        Queue::instance()->enqueue(make_job([]() {})); // nop
         Queue::instance()->finish();
         QCOMPARE(counter.loadAcquire(), 2);
     }
